﻿using System;
using System.Web.UI;
using Telerik.Sitefinity;
using Telerik.Sitefinity.Configuration;
using Telerik.Sitefinity.Modules.Pages;
using Telerik.Sitefinity.Pages.Model;
using Telerik.Sitefinity.Web;
using Telerik.Sitefinity.Web.Configuration;

namespace RWCC
{
    namespace Sitefinity
    {
        public static class Utilities
        {
            public static void AddTogglePageThemeScript(System.Web.UI.MasterPage master)
            {
                if (master.IsDesignMode() && !master.IsPreviewMode())
                {
                    string togglePageThemeScript = GetTogglePageThemeScript();
                    if (!String.IsNullOrEmpty(togglePageThemeScript))
                    {
                        ScriptManager.RegisterStartupScript(master, master.GetType(), "sfTogglePageTheme", togglePageThemeScript, true);
                    }
                }
            }

            public static string GetPageThemeName()
            {
                string name = null;

                PageSiteNode psn = SiteMapBase.GetActualCurrentNode();
                if (psn != null)
                {
                    PageManager pm = PageManager.GetManager();
                    PageNode pn = pm.GetPageNode(psn.Id);
                    PageData pd = pm.GetPageData(pn.PageId);
                    name = (pd != null && pd.Template != null) ? pd.Template.Theme : "";
                    if (String.IsNullOrEmpty(name) && pd.Template != null)
                    {
                        PageTemplate template = pd.Template;
                        while (String.IsNullOrEmpty(name) && template.ParentTemplate != null)
                        {
                            template = template.ParentTemplate;
                            name = template.Theme;
                        }
                    }
                }

                return name;
            }

            public static string GetPageThemePath()
            {
                return GetPageThemePath(true);
            }
            public static string GetPageThemePath(bool useBrowsablePath)
            {
                string name = GetPageThemeName();
                string path = null;

                if (!String.IsNullOrEmpty(name))
                {
                    ConfigManager configManager = ConfigManager.GetManager();
                    configManager.Provider.SuppressSecurityChecks = true;
                    AppearanceConfig appearanceConfig = configManager.GetSection<AppearanceConfig>();
                    if (appearanceConfig.FrontendThemes[name] != null)
                    {
                        path = ((ThemeElement)appearanceConfig.FrontendThemes[name]).Path;
                        if (useBrowsablePath && path.StartsWith("~/App_Data", StringComparison.OrdinalIgnoreCase))
                        {
                            path = path.Substring(10);
                        }
                    }
                }

                return path;
            }

            public static string GetTogglePageThemeScript()
            {
                string pageThemePath = GetPageThemePath();
                return (!String.IsNullOrEmpty(pageThemePath)) ? @"jQuery(document).ready(function() { $('<div class=""sfInlineBlock""><a class=""sfLinkBtn"" id=""togglePageTheme""><span class=""sfLinkBtnIn"">Disable Page Theme</span></a></div>').appendTo('div.sfWorkflowMenuWrp'); $('#togglePageTheme').click(function(){ var pageThemeLinks = $('link[href*=""" + pageThemePath.Replace("~/", "/") + @"""]'); if (pageThemeLinks.length > 0) { if (pageThemeLinks.filter(""link[disabled='disabled']"").length > 0) { pageThemeLinks.removeAttr('disabled'); $('#togglePageTheme > span.sfLinkBtnIn').html('Disable Page Theme'); } else { pageThemeLinks.attr('disabled', 'disabled'); $('#togglePageTheme > span.sfLinkBtnIn').html('Enable Page Theme'); } } return false; }); });" : "";
            }
        }
    }
}

